#!/usr/bin/env python
# encoding: utf-8

import logging
import os
import sys
from adl_common import configure_logging, check_and_convert_path
from adl_common import check_existing_env_var, status_line
from adl_common import CSPP_RT_HOME
import traceback
import datetime as dt
import sqlite3
import re
import time
import shutil
import glob
from stat import *
from adl_common import get_shipped_db
import tempfile
import pprint as pp

LOG = logging.getLogger(__name__)

# use this set of required keys when scanning RDR granules with skim_dir
RDR_REQUIRED_KEYS = [
    'N_Granule_ID', 'n_collection_short_name', 'StartTime', 'EndTime']
POLARWANDER_REQUIRED_KEYS = [
    'EffectiveStartTime', 'EffectiveEndTime', 'n_collection_short_name', 'N_Software_Version']

SOFT_VERSION_KEY = 'N_Software_Version'

# 'COLLECTION_SHORT_NAME',

NEEDED_PROPS = ['GRANULE_ID', 'RANGE_START_IET', 'RANGE_STOP_IET', 'EFFECTIVITY_START_IET',
                'EFFECTIVITY_STOP_IET', 'PRODUCT_ID', 'GRANULE_VERSION']

NEEDED_PROPS_DT = ['RANGE_START_IET', 'RANGE_STOP_IET', 'EFFECTIVITY_START_IET',
                   'EFFECTIVITY_STOP_IET']

NEEDED_SHORT_NAMES = ['VIIRS-SCIENCE-RDR', 'CRIS-SCIENCE-RDR', 'ATMS-SCIENCE-RDR',
                      'SPACECRAFT-DIARY-RDR',
                      'VIIRS-RSBAUTOCAL-HISTORY-AUX', 'TLE-AUX-Int']

COMPAT = {'RANGE_START_IET': 'StartTime', 'EFFECTIVITY_START_IET': 'StartTime', 'GRANULE_VERSION':
          'N_Granule_Version','GRANULE_ID': 'N_Granule_ID'}

global_database_name = None
sud_dir_list = ['AUX', 'ANC']

PACKAGE_DATABASE = 'cspp_sdr_package.db'
CACHE_DATABASE = 'cspp_sdr_cache.db'
WORK_DATABASE = 'cspp_sdr_work.db'
SHIPPED_LUTS = 'shipped_luts'
INCOMING_LUTS = 'incoming_luts'


def shipped_luts_abs_path():
    """
    """
    return os.path.join(CSPP_RT_HOME, 'anc', 'static', SHIPPED_LUTS)


def incoming_luts_abs_path():
    """
    """
    return os.path.join(CSPP_RT_HOME, 'anc', 'cache', INCOMING_LUTS)


def replace_file_with_link(cached_file, file_to_link):
    """
    """
    if not os.path.exists(cached_file):
        LOG.error("No cached file %s" % cached_file)
        return

    LOG.debug('SOFT LINK src %s dest %s' % (cached_file, file_to_link))
    if not os.path.islink(cached_file):
        tname=file_to_link+".t"
        os.symlink(cached_file, tname)
        os.rename(tname,file_to_link)
        
    if not os.path.islink(file_to_link):
        LOG.error('link failed %s'%file_to_link)


def create_anc_soft_links(use_db, lut_cache):
    """
    """
    if os.path.isfile(use_db) :
        db_files = os.path.dirname(use_db)
    else :
        db_files = use_db
        
    all_files_back = glob.glob(os.path.join(lut_cache, "*.*"))

    for lutaux in all_files_back:
        if not lutaux.endswith("lock") :
            lookfor = os.path.basename(lutaux)
            done = False
            for root, dirs, files in os.walk(db_files):
                for f in files:
                    #LOG.info('file %s %s'%(f, lookfor))
                    if lookfor in f:
                        LOG.info('found %s' % f)
                        replace_file_with_link(lutaux, os.path.join(root, f))
                        done = True
                if done:
                    break






def count_soft_links(indir):
    """
    """
    links = 0
    for root, dirs, files in os.walk(indir):
        for f in files:
            #LOG.info('file %s'%(f))
            if  os.path.islink(os.path.join(root,f)):
                    links += 1

    #LOG.info('lnks %s'% str(links))   
    
    if links == 0 :
        LOG.warn('\n   (Installation my be incomplete! Please run sdr_luts.sh)\n')        
    return links



def create_lut_soft_links(use_db, lut_cache):
    """
    """
    if os.path.isfile(use_db) :
        db_files = os.path.dirname(use_db)
    else :
        db_files = use_db
        
    all_files_back = glob.glob(os.path.join(lut_cache, "*.*"))

    for lutaux in all_files_back:
        if not lutaux.endswith("lock") :
            lookfor = os.path.basename(lutaux)
            done = False
            for root, dirs, files in os.walk(db_files):
                for f in files:
                    #LOG.info('file %s %s'%(f, lookfor))
                    if lookfor in f:
                        LOG.debug('found %s' % f)
                        replace_file_with_link(lutaux, os.path.join(root, f))
                        done = True
                if done:
                    break


def create_cache_database(cspp_sdr_home, overwrite=True):
    """
    """
    # copy the PACKAGE_DATABASE to the daily_location
    global global_database_name

    package_dms_path =  os.path.dirname(get_shipped_db(cspp_sdr_home) )
    
    luts_cache = os.path.join(cspp_sdr_home, 'anc', 'cache', INCOMING_LUTS)
    
    #shipped_luts_abs_path():

    #tmp_dms_path = os.path.join(cspp_sdr_home, 'anc', 'cache', 'tmp')
    tf= tempfile.TemporaryDirectory(prefix='tmp', dir=os.path.join(cspp_sdr_home, 'anc', 'cache'))
    tmp_dms_path = os.path.join(tf.name,"tmp")
    
    ##tmp_dms_path = os.path.join(cspp_sdr_home, 'anc', 'cache','tmp')
  
    cache_dms_path = os.path.join(cspp_sdr_home, 'anc', 'cache',  'db')

    LOG.debug(package_dms_path)
    LOG.debug(tmp_dms_path)
    LOG.debug(cache_dms_path)

    if not os.path.exists(cache_dms_path):
        overwrite = True

    if overwrite is True:
        status_line('One time initialization, takes some time')

        shutil.rmtree(tmp_dms_path, ignore_errors=True)

        startTime = time.time()

        LOG.debug('copy %s to \n %s' % (package_dms_path, tmp_dms_path))

        dms_dest_db = os.path.join(tmp_dms_path, CACHE_DATABASE)
        tmp_db = os.path.join(tmp_dms_path, PACKAGE_DATABASE)

        shutil.copytree(package_dms_path, tmp_dms_path, symlinks=True)
        os.rename(tmp_db,dms_dest_db)

        luts_cache = shipped_luts_abs_path()
        create_lut_soft_links(tmp_dms_path, luts_cache)

        luts_cache = incoming_luts_abs_path()
        create_lut_soft_links(tmp_dms_path, luts_cache)

        endTime = time.time()
        delta = endTime - startTime

        status_line('Execution Time: %f Sec ' % delta)

        #os.rename(tmp_db, dms_dest_db)
        # shutil.rmtree(os.path.dirname(cache_dms_path), ignore_errors=True)
        os.rename(tmp_dms_path, cache_dms_path)

    dms_dest_db = os.path.join(cache_dms_path, CACHE_DATABASE)
    global_database_name = "file:" + dms_dest_db + ":?cache=shared"
    global_database_name = dms_dest_db



    return dms_dest_db


def setup_dms_in_work_directory(work_dir, cspp_sdr_home):
    """
    Copy the dms and make needed links in work directory
    :return:
    """
    global global_database_name

    cache_dms_path = os.path.join(cspp_sdr_home, 'anc', 'cache',  'db')
    # dms_initial_db = os.path.join(cache_dms_path, CACHE_DATABASE)

    if not os.path.exists(cache_dms_path):
        create_cache_database(cspp_sdr_home)

    working_dms_path = os.path.join(work_dir, 'db')
    dms_dest_db = os.path.join(working_dms_path, WORK_DATABASE)
    global_database_name = dms_dest_db
    if not os.path.exists(working_dms_path):
        # LOG.info('Copy dms')
        os.makedirs(os.path.join(working_dms_path, 'DmSm'))
        shutil.copyfile(os.path.join(cache_dms_path, CACHE_DATABASE) , os.path.join(working_dms_path, WORK_DATABASE))
     
        for sub in ['Terrain-Eco-ANC-Tile' ]:
            src_dir = os.path.join(cache_dms_path, 'DmSm', sub)
            link_name = os.path.join(working_dms_path, 'DmSm', sub)
            LOG.debug('link %s %s'%(src_dir, link_name))
            os.symlink(src_dir, link_name)

        for sub in 'AUX-Int', 'AUX', 'ANC',  'ANC-Int', 'RDR', 'SDR', 'GEO', 'IP', 'HDF', 'DQN', 'TDR':
            src_dir = os.path.join(cache_dms_path, 'DmSm', sub)
            dest_dir = os.path.join(working_dms_path, 'DmSm', sub)
            shutil.copytree(src_dir, dest_dir, symlinks=True)

        perm= S_IRUSR | S_IWUSR | S_IXUSR
           
        for root, dirs, files in os.walk(os.path.join(working_dms_path, 'db'), followlinks=False):
                for d in dirs:
                    os.chmod(os.path.join(root, d), perm)
                for f in files:
                    os.chmod(os.path.join(root, f), perm)
            
            
    else:
        LOG.warn('DMS copy skipped %s already exists' % working_dms_path)


    LOG.info('global name %s'%global_database_name)
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()

    table = 'TDMS_COREFL_CORE_FILES'
    myproperty = 'DEVICE_NAME'


    dms_tiles = os.path.join(cspp_sdr_home, 'anc', 'static', 'ecotiles')
    old_value = '%anc/static/ecotiles%'
 
    cmd = 'UPDATE %s SET %s = "%s" WHERE %s LIKE "%s"' % (
        table, myproperty, dms_tiles, myproperty, old_value)
    LOG.debug(cmd)
    cursor.execute(cmd)
    conn.commit()
    conn.close()

    count_soft_links(working_dms_path)

    return global_database_name


def update_orbit_number(orbit_number, granule_id):
    """
    """

    g_id = 'GRANULE_ID'
    'RANGE_START_IET'

    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()

    table = 'TDMS_COREUR_CORE_URS'
    
    myproperty = 'BEGIN_ORBIT_NUMBER'

    cmd = 'UPDATE %s SET %s = "%s" WHERE %s LIKE "%s"' % (
        table, myproperty, orbit_number, g_id, granule_id)
    LOG.debug(cmd)

    cursor.execute(cmd)
    conn.commit()
    conn.close()
    
def check_science_RDR(spcrft='NPP'):
    """
    """
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()


    cmd = 'SELECT  COREUR_ID FROM TDMS_COREMD_METADATA where STRING_VALUE LIKE "%SPACECRAFT"'
    LOG.debug(cmd)
    cursor.execute(cmd)

    core_urids=cursor.fetchall()
    LOG.debug(core_urids)

    conn.commit()
    conn.close()
    
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()

    work_dms_files = os.path.join(os.path.dirname(global_database_name),'DmSm')

    for coreur_id in core_urids:
    
        cmd = 'SELECT  DEVICE_NAME FROM TDMS_COREFL_CORE_FILES where COREUR_ID LIKE "%s"'%coreur_id
        LOG.debug(cmd)
        cursor.execute(cmd)
        device=cursor.fetchall()
        filepath=os.path.join(work_dms_files,device[0][0],"*.CRIS-SCIENCE-RDR")

        filenames=glob.glob(filepath)
 
        for filename in filenames:
            if os.path.isfile(filename) :
 
                npp_sizes=[7300000,9390240,7313248,7260174]  # ,9375552,9383282
                jpss_sizes=[9390240,9397970] 
                if spcrft=='NPP' :
                    sizes = npp_sizes
                else :
                    sizes = jpss_sizes
               
                fsize = int(os.path.getsize(filename))
                ok = False
                for gsize in sizes:
                    LOG.debug('%s %d %d'%(filename,os.path.getsize(filename),gsize))
                    if (gsize <=  fsize)   :
                        ok =True
                        
                if not ok:
                    LOG.info('Removed CRIS-SCIENCE-RDR %s %s %s'%(spcrft,filename,str(os.path.getsize(filename))))
                    smallfile=filename+".small"
                    os.rename(filename,smallfile)
                    urid=os.path.basename(filename).split(".")[0]
                    cmd = 'DELETE FROM TDMS_COREUR_CORE_URS where URID LIKE "%s" '%urid
                    LOG.debug(cmd)
                    cursor.execute(cmd)
                    #result=cursor.fetchall()
             
    conn.commit()
    conn.close()
    
def check_atms_science_RDR(spcrft='NPP'):
    """
    """
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()


    cmd = 'SELECT  COREUR_ID FROM TDMS_COREMD_METADATA where STRING_VALUE LIKE "%SPACECRAFT"'
    LOG.debug(cmd)
    cursor.execute(cmd)

    core_urids=cursor.fetchall()
    LOG.debug(core_urids)

    conn.commit()
    conn.close()
    
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()

    work_dms_files = os.path.join(os.path.dirname(global_database_name),'DmSm')

    all_rdr_sizes=[]

    for coreur_id in core_urids:
    
        cmd = 'SELECT  DEVICE_NAME FROM TDMS_COREFL_CORE_FILES where COREUR_ID LIKE "%s"'%coreur_id
        LOG.debug(cmd)
        cursor.execute(cmd)
        device=cursor.fetchall()

        filepath=os.path.join(work_dms_files,device[0][0],"*.ATMS-SCIENCE-RDR")
        filenames=glob.glob(filepath)
 
        for filename in filenames:
            if os.path.isfile(filename) :
 
                npp_sizes= [111102,111042]  # ,9375552,9383282
                jpss_sizes=[111102,111042] 
 
                if spcrft=='NPP' :
                    sizes = npp_sizes
                else :
                    sizes = jpss_sizes
               
                fsize = int(os.path.getsize(filename))
                
                all_rdr_sizes.append(fsize)
                
                ok = False
                for gsize in sizes:
                    LOG.debug('%s %d %d'%(filename,os.path.getsize(filename),gsize))
                    if (gsize <=  fsize)   :
                        ok =True
                        
                if not ok:
                    LOG.info('Removed ATMS-SCIENCE-RDR %s %s %s'%(spcrft,filename,str(os.path.getsize(filename))))
                    smallfile=filename+".small"
                    os.rename(filename,smallfile)
                    urid=os.path.basename(filename).split(".")[0]
                    cmd = 'DELETE FROM TDMS_COREUR_CORE_URS where URID LIKE "%s" '%urid
                    LOG.debug(cmd)
                    cursor.execute(cmd)
                    #result=cursor.fetchall()
             
    conn.commit()
    conn.close()    
    
    
    all_rdr_sizes=sorted(set(all_rdr_sizes))
    LOG.info("%s RDR sizes %s"%(spcrft,pp.pformat(all_rdr_sizes)))
    
    

def check_spacecraft_diaries(spcrft='NPP'):
    """
    """
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()


    cmd = 'SELECT  COREUR_ID FROM TDMS_COREMD_METADATA where STRING_VALUE LIKE "%SPACECRAFT"'
    LOG.debug(cmd)
    cursor.execute(cmd)

    core_urids=cursor.fetchall()
    LOG.debug(core_urids)

    conn.commit()
    conn.close()
    
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()

    work_dms_files = os.path.join(os.path.dirname(global_database_name),'DmSm')

    for coreur_id in core_urids:
    
        cmd = 'SELECT  DEVICE_NAME FROM TDMS_COREFL_CORE_FILES where COREUR_ID LIKE "%s"'%coreur_id
        LOG.debug(cmd)
        cursor.execute(cmd)
        device=cursor.fetchall()
        filepath=os.path.join(work_dms_files,device[0][0],"*.SPACECRAFT-DIARY-RDR")
        filenames=glob.glob(filepath)
 
        for filename in filenames:
            #LOG.debug('%s %d '%(filename,os.path.getsize(filename)))

            if 14340 != os.path.getsize(filename) & 14620 != os.path.getsize(filename) :
                LOG.info('Removed SPACECRAFT-DIARY-RDR %s %s'%(filename,str(os.path.getsize(filename))))
                smallfile=filename+".small"
                os.rename(filename,smallfile)
                urid=os.path.basename(filename).split(".")[0]
                cmd = 'DELETE FROM TDMS_COREUR_CORE_URS where URID LIKE "%s" '%urid
                LOG.debug(cmd)
                cursor.execute(cmd)
                #result=cursor.fetchall()



             
    conn.commit()
    conn.close()
   
def get_product_ids(spcrft='NPP'):
    """
    """
    LOG.debug('Open %s' % global_database_name)
    property_lookup = {}
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()

    cursor.execute('SELECT name FROM sqlite_master WHERE type=\'table\';')
    tables = cursor.fetchall()
    LOG.debug(tables)

    for table_info in tables:

        info_str = str(table_info)
        table_name = re.search('[a-zA-Z0-9_]+', info_str)
        table_name = info_str[table_name.start():table_name.end()]
        # LOG.info('Table %s' % (table_name))
        # Retrieve column information
        # Every column will be represented by a tuple with the following attributes:
        # (id, name, type, notnull, default_value, primary_key)
        cursor.execute('PRAGMA TABLE_INFO({})'.format(table_name))

        # collect names in a list
        names = [tup[1] for tup in cursor.fetchall()]
        for name in names:
            props = NEEDED_PROPS
            # props.append('COLLECTION_SHORT_NAME')
            if name in props + ['COLLECTION_SHORT_NAME']:
                LOG.debug('%s Property %s' % (table_name, name))
                property_lookup[name] = table_name

    product_id = {}

    # now find the product ids and shortname
    # find the product ids
    product_table = property_lookup['COLLECTION_SHORT_NAME']
    for short_name in NEEDED_SHORT_NAMES:
        query = (
            'SELECT * FROM {0:s} WHERE {1:s} LIKE "{2:s}" AND PLATFORM_SHORT_NAME like "{3:s}" '.format(product_table,
                                                                                                        'COLLECTION_SHORT_NAME',
                                                                                                        short_name,
                                                                                                        spcrft))
        LOG.debug(query)
        cursor.execute(query)
        # cursor.execute('SELECT * FROM {tn} WHERE {cn} LIKE "{cv}"'.\
        # format(tn=product_table, cn='COLLECTION_SHORT_NAME', cv=short_name))

        all_rows = cursor.fetchall()
        for row in all_rows:
            product_id[row[1]] = row[0]

    conn.close()

    return product_id, property_lookup


def lookup_by_product_id_and_replace_value(myproperty, new_value, old_value):
    """
    :param product_id:
    :return:
    """
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()

    table = 'TDMS_COREUR_CORE_URS'

    cmd = 'UPDATE %s SET %s = "%s" WHERE %s = "%s"' % (
        table, myproperty, new_value, myproperty, old_value)
    LOG.info(cmd)

    cursor.execute(cmd)
    conn.commit()
    conn.close()
    return

def get_granule_ids(short_name, product_ids, property_lookup):
    """
    return a list of dictionrys with the only element being the granule id
    """

    short_name_properties = []

    conn = sqlite3.connect(global_database_name)

    cursor = conn.cursor()

    prop = 'GRANULE_ID'
    table = property_lookup[prop]

    query = ('SELECT %s FROM %s WHERE %s LIKE "%s"  ' % (prop,
                                                         table, 'PRODUCT_ID',
                                                         product_ids[short_name]))

    LOG.debug(query)
    # cursor.execute(query)
    # srm ?all_rows = cursor.fetchall()
    for row in cursor.execute(query):
        gstr = row[0]
        gran_id_value = re.search('[a-zA-Z0-9_]+', gstr)
        gran_id = gstr[gran_id_value.start():gran_id_value.end()]

        info = {}
        info[prop] = gran_id
        short_name_properties.append(info)

    conn.close()
    return short_name_properties


def get_granule_properties(granule_ids, property_lookup):
    """
    return a list of dictionrys with the only element being the granule id
    """
    conn = sqlite3.connect(global_database_name)
    cursor = conn.cursor()

    prop = 'GRANULE_ID'
    table = property_lookup[prop]

    for info in granule_ids:
        for prop in NEEDED_PROPS:

            query = ('SELECT {0:s} FROM {1:s} WHERE {2:s} LIKE "{3:s}"  '.format(prop,
                                                                                 table, 'GRANULE_ID',
                                                                                 info['GRANULE_ID']))

            # LOG.debug(query)

            try:
                # LOG.debug('prop %s' % str(prop))
                for row in cursor.execute(query):
                    if row[0] is not None:
                        gstr = str(row)
                        prop_re = re.search('[a-zA-Z0-9_]+', gstr)
                        prop_value = gstr[prop_re.start():prop_re.end()]
                        info[prop] = prop_value
                        # LOG.debug('prop %s val %s' % (str(prop), prop_value))
                    else:
                        info[prop] = None
                        # LOG.debug('set prop %s val %s' % (str(prop), info[prop]))

            except Exception:
                LOG.error(traceback.format_exc())
                pass

    conn.close()
    return granule_ids

from operator import itemgetter
def skim_dir(n_collection_short_name='SPACECRAFT-DIARY-RDR', spcrft='NPP'):
    """yield a sequence of metadata dictionaries with optional keyword-content filtering
    optionally include iterable required_keys listing keys which must be available in the generated dictionaries
    this can also be accomplished by setting a matchkey as None, e.g. N_Granule_ID=None
    """
    LOG.debug('n_collection_short_name %s spcrft %s'%(n_collection_short_name,spcrft))
    short_name = n_collection_short_name
    # desired products ids and where the properties can be found
    product_ids, property_lookup = get_product_ids(spcrft=spcrft)
    LOG.debug(product_ids)
    LOG.debug(property_lookup)

    granule_ids = get_granule_ids(short_name, product_ids, property_lookup)
    if len(granule_ids) == 0: 
        LOG.warn('Granules not found, possible RDR problem. Check RDR acquisition software version %s %s'%(short_name,spcrft))
        return None
    
    granule_ids2 = get_granule_properties(granule_ids, property_lookup)

    for gran in granule_ids2:
        for convert_me in NEEDED_PROPS_DT:
            if gran[convert_me] is not None:
                LOG.debug('convert %s %s' % (str(convert_me), gran[convert_me]))
                granule_time = gran[convert_me]
                epoch = dt.datetime(1958, 1, 1)
                delta = dt.timedelta(microseconds=int(granule_time))
                gran[convert_me] = epoch + delta

    for gran in granule_ids2:
        for item in COMPAT:
            if item in gran:
                if COMPAT[item] in gran:  # already added
                    if gran[COMPAT[item]] is None:
                        LOG.debug('Replace/insert %s %s ' % (item, COMPAT[item]))
                        gran[COMPAT[item]] = gran[item]

                else:
                    # add it
                    LOG.debug('Add %s %s ' % (item, COMPAT[item]))
                    gran[COMPAT[item]] = gran[item]

    newlist = sorted(granule_ids2, key=itemgetter('N_Granule_ID'))

    last_list = list()
    b_gran = newlist[0]
    for gran in newlist[1:]:
        if b_gran['N_Granule_ID'] == gran['N_Granule_ID']:
            LOG.info('Duplicate found %s %s %s' % ( b_gran['N_Granule_ID'],gran['GRANULE_VERSION'],b_gran['GRANULE_VERSION']))
            if gran['GRANULE_VERSION']  < b_gran['GRANULE_VERSION'] :
                last_list.append( b_gran)      
        else :
            last_list.append( b_gran)     

        b_gran = gran

    last_list.append( b_gran)
    LOG.debug(pp.pformat(last_list ))
    for info in last_list:
        yield info


def main():
    """ Run Viirs SDR proccessing
    """
    import argparse

    desc = """Build VIIRS SDR ProSdrViirsDBController work directory and run VIIRS SDR.
        viirs_sdr.sh wraps the python code, adl_viirs_sdr.py options are passed through."""
    parser = argparse.ArgumentParser(description=desc)

    parser.add_argument('-W', '--work-dir', metavar='work_dir', default='.',
                        help='directory in which all activity occurs, defaults to current dir')

    parser.add_argument('-d', '--debug',
                        action="store_true", default=False, help="always retain intermediate files")

    parser.add_argument('-v', '--verbosity', action="count", default=0,
                        help='each occurrence increases verbosity 1 level ERROR-WARNING-INFO-DEBUG')

    parser.add_argument("cspp_sdr_home", nargs='+', help='cspp_sdr_home')

    args = parser.parse_args()

    levels = [logging.ERROR, logging.WARN, logging.INFO, logging.DEBUG]
    level = levels[args.verbosity if args.verbosity < 4 else 3]

    work_dir = check_and_convert_path("WORK_DIR", args.work_dir)
    # d = dt.datetime.now()
    # timestamp = d.isoformat()
    # logname = "viirs_sdr." + timestamp + ".log"
    # logfile = os.path.join(work_dir, logname)
    # configure_logging(level, FILE=logfile)
    configure_logging(level)

    dpe_version = check_existing_env_var('DPE_VER', default_value='cspp')
    LOG.info("product version: DPE_VER for VIIRS SDR  %s" % dpe_version)

    # check_anc_cache(check_write=not args.local)
    LOG.info('CSPP execution work directory is %r' % work_dir)

    if not args:
        parser.print_help()
        return 1

    rc = 1
    return rc


if __name__ == '__main__':
    sys.exit(main())
